define(
//begin v1.x content
{
	"HKD_displayName": "Хонгконшки долар",
	"CNY_displayName": "Кинески јуан",
	"JPY_displayName": "Јапонски јен",
	"JPY_symbol": "JPY",
	"USD_displayName": "Американски долар",
	"CAD_symbol": "CA$",
	"GBP_displayName": "Британска Фунта",
	"CHF_displayName": "Швајцарски Франк",
	"CNY_symbol": "CNY",
	"EUR_displayName": "Евро",
	"GBP_symbol": "GBP",
	"CAD_displayName": "Канадски долар",
	"USD_symbol": "US$",
	"EUR_symbol": "€",
	"AUD_displayName": "Австралиски долар",
	"CHF_symbol": "CHF",
	"HKD_symbol": "HKD",
	"AUD_symbol": "AUD"
}
//end v1.x content
);